//-----------------------------------------------------------------------------
// Title      : Beispiel fuer EADOGM, EADOGL oder MK3-LCD
//-----------------------------------------------------------------------------
// Funktion   : LCD Test
// Schaltung  : siehe lcd_treiber.h
//-----------------------------------------------------------------------------
// Prozessor  : ATMega2560 oder ATmega644
// Takt       : 16 MHz     oder 20 MHz
//-----------------------------------------------------------------------------
#ifdef ATMEGA644
#define F_CPU 20000000
#else
#define F_CPU 16000000
#endif
#include <avr/io.h>
#include "lcd_treiber.c"

int main (void)
{
	unsigned int n;
	//char led_wert=0;
	char x,y;

#ifdef ATMEGA644
	DDRD |= (1<<5)|(1<<6); //LED1+LED2 auf dem Funkevaluationsboard
#endif

	glcd_init();				// init des LCD
	glcd_clear();				// LCD loeschen
	glcd_licht(true);			// beleuchtung einschalten

	for(x=0;x<3;x++) //test LCD-Hintergrundlicht 3 mal blinken
	 {
	  MILLIWAIT(300);
	  glcd_licht(false);
	  MILLIWAIT(300);
	  glcd_licht(true);			// beleuchtung einschalten
	 }

	// zeichnet eine Reihe mit 0x55
	glcd_cursor(0,0);
	PORTD &= ~(1<<5); //erste aus
	for(n=0;n<LCD_MAXX;n++) {
		 lcdSendData(0x55);
	}
	MILLIWAIT(1000); //test

	// zeichnet eine Reihe mit 127 bis 0
	glcd_cursor(0,16);
	for(n=0;n<LCD_MAXX;n++) {
		 lcdSendData(n);
	}
	MILLIWAIT(1000); //test

	// zeichne eine waagrechte Linie (schwarz)
	glcd_cursor(x=2,y=48);
	glcd_lineto(x=126,y);
	MILLIWAIT(1000); //test

	// zeichne eine senkrechte Linie (schwarz)
	glcd_cursor(x=2,y=2);
	glcd_lineto(x,48);
	MILLIWAIT(1000); //test

	// zeichnet eine schraege Linie (schwarz)
	glcd_cursor(x=0,y=63);
	glcd_lineto(x+100,y-10);
	MILLIWAIT(1000); //test

	// zeichnet eine schraege Linie (schwarz)
	glcd_cursor(x=10,y=0);
	glcd_lineto(x+50,50);
	MILLIWAIT(1000); //test
	
	// zeichnet eine schraege Linie (weiss)
	glcd_drawmode(MODE_REVERS);
	glcd_cursor(x=40,0);
	glcd_lineto(x+50,50);
	MILLIWAIT(1000); //test
	
	// zeichnet eine schraege Linie (invers)
	glcd_drawmode(MODE_TOGGLE);
	glcd_cursor(x=70,0);
	glcd_lineto(x+50,50);

	MILLIWAIT(3000);

	// Schreibt das Alfabet auf:
	/*
	int dy=15;
	glcd_cursor(x=0,y=0);
	glcd_print("VOGT NYX: BUESS DU JA");
	glcd_cursor(0,y+=dy);
	glcd_print("ZWOLF QIRSCH, KAEMPE!");
	glcd_cursor(0,y+=dy);
	glcd_print("vogt nyx: buess du ja");
	glcd_cursor(0,y+=dy);
	glcd_print("zwolf qirsch, kaempe?");
	//glcd_cursor(0,y+=dy);
	//glcd_print("Vogt Nyx: B�� du ja zw�lf Qirsch, K�mpe!");
	*/

	// Variante mit Umlauten und Zeilenumbruch:
	glcd_cursor(x=0,y=0);
	setze_zeilenabstand(15);
	glcd_print("VOGT NYX: BÜSS DU JA ZWÖLF QIRSCH, KÄMPE!\n");
	glcd_print("vogt nyx: büß du ja zwölf qirsch, kämpe?\n");

	// MILLIWAIT(10000); glcd_off(); //test

	while (true)
	{
#ifdef ATMEGA644
	  PORTD |= (1<<5)|(1<<6); //beide einschalten
	  MILLIWAIT(250); //0.25 Sek lang
	  PORTD &= ~((1<<5)|(1<<6)); //beide aus
	  MILLIWAIT(250); //0.25 Sek lang
#endif
	}
	return 0;
}
//-----------------------------------------------------------------------------
